@@ -2,6 +2,16 @@ from typing import TYPE_CHECKING, Any, Dict, Optional
 
 from starlette.testclient import TestClient
 
+try:
+    from devtools.prettier import pformat
+except ImportError:
+    from pprint import pformat
+
+try:
+    import pytest
+except ImportError:
+    pytest = None
+
 if TYPE_CHECKING:
     from requests import Response
 
@@ -26,8 +36,7 @@ class Client(TestClient):
         **kwargs,
     ) -> Dict[str, Any]:
         r = self.get(url, allow_redirects=allow_redirects, headers=headers, **kwargs)
-        if status:  # pragma: no cover
-            assert r.status_code == status, r.text
+        check_response(r, status)
         return r.json()
 
     def post_json(
@@ -41,6 +50,26 @@ class Client(TestClient):
         **kwargs,
     ) -> Dict[str, Any]:
         r = self.post(url, json=json, allow_redirects=allow_redirects, headers=headers, **kwargs)
-        if status:
-            assert r.status_code == status, r.text
+        check_response(r, status)
         return r.json()
+
+
+def check_response(response: 'Response', expected_status: Optional[int]) -> None:
+    if expected_status is None or response.status_code == expected_status:
+        return
+
+    try:
+        body = pformat(response.json())
+    except ValueError:
+        body = response.text
+
+    req = response.request
+    msg = (
+        f'{req.method} {req.url} returned unexpected status: {response.status_code} (expected {expected_status}), '
+        f'body:\n{body}'
+    )
+
+    if pytest:  # pragma: no branch
+        pytest.fail(msg)
+    else:  # pragma: no cover
+        raise ValueError(msg)
